<?php
// 
$MOWIKI_DATA = 'data/';
$MOWIKI_LIB = 'lib/';
$MOWIKI_VIEW = 'view/';

// WiKi^CgAǗҖ
$MOWIKI_TITLE = 'MoWiKi';
$MOWIKI_ADMIN = 'Randolph';

// \F̐ݒ
$MOWIKI_BG = '#AAAAFF';
$MOWIKI_TEXT = '#000000';
$MOWIKI_LINK = '#0000FF';
$MOWIKI_ALINK = '#006666';
$MOWIKI_VLINK = '#006666';
$MOWIKI_HR = '#000000';

// ӏ̃^OݒB
//  Ƃƌgтœ͂₷ȂłB

$MOWIKI_LI0 = ' ';
$MOWIKI_LI1 = ' ';
$MOWIKI_LI2 = ' ';

// LbVׂ̗̈
srand(time());
$MOWIKI_RAND = rand(0,1000000);

// Xg\ł̍őy[W
$MOWIKI_LIST_MAX = 20;

// tɕϊ镶
$MOWIKI_DATE = 't';
$MOWIKI_DATE_FORMAT = 'yNmd';

// ɕϊ镶
$MOWIKI_TIME = '';
$MOWIKI_TIME_FORMAT = 'H:i:s';
?>